@@ -1,7 +1,9 @@
 """Email utils
 """
 
+import re
+
 
 def is_email(email: str) -> bool:
     """Assert that email has minimun requirements."""
-    return "@" in email
+    return re.search(r".+@.+\..+", email) is not None
